systemrecord

package
v0.1.0-alpha.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 24, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package systemrecord defines the private bridge between the root database and higher-level built-in services. It is internal so applications cannot depend on raw control-plane records as a public key/value API.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Backend

type Backend interface {
	CompareAndSwap(context.Context, Mutation) (Result, error)
	Scan(context.Context, []byte, []byte, int) ([]KeyValue, error)
}

type KeyValue

type KeyValue struct {
	Key   []byte
	Value []byte
}

type Mutation

type Mutation struct {
	TransactionID  [16]byte
	Key            []byte
	ExpectedExists bool
	ExpectedHash   [32]byte
	NewValue       []byte
	Delete         bool
	Unconditional  bool
}

type Result

type Result struct {
	Applied bool
	Current []byte
}

Jump to